summaryrefslogtreecommitdiff
path: root/server.go
diff options
context:
space:
mode:
Diffstat (limited to 'server.go')
-rw-r--r--server.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/server.go b/server.go
index d1757207..8f8e9382 100644
--- a/server.go
+++ b/server.go
@@ -63,8 +63,8 @@ func (s *Server) Listen(l func(event int, ctx interface{})) {
s.lsn = l
}
-// AddController attaches worker controller.
-func (s *Server) Watch(c Controller) {
+// Attach attaches worker controller.
+func (s *Server) Attach(c Controller) {
s.mu.Lock()
defer s.mu.Unlock()
@@ -102,7 +102,7 @@ func (s *Server) Start() (err error) {
return nil
}
-// Detach underlying worker pool and close the factory.
+// Stop underlying worker pool and close the factory.
func (s *Server) Stop() {
s.mu.Lock()
defer s.mu.Unlock()